Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func PrintError ¶
func PrintError(err error)
func PrintFatal ¶
func PrintFatal(err error)
func PrintProperty ¶
func PrintProperty(name, value string)
func PrintResult ¶
Types ¶
type ProgressBar ¶ added in v0.2.0
ProgressBar - A structure that controls displaying a progress bar in the console.
func NewProgress ¶ added in v0.2.0
func NewProgress(max int) *ProgressBar
NewProgress - Creates a new progress bar with a given maximum value.
func (*ProgressBar) Inc ¶ added in v0.2.0
func (bar *ProgressBar) Inc()
Inc - Increments the current value by one.
func (*ProgressBar) Stop ¶ added in v0.2.0
func (bar *ProgressBar) Stop()
Stop - Stops the progress bar rendering. This is automatically called if the current value reaches the maximum.
Click to show internal directories.
Click to hide internal directories.